==> haskell-primitive-unaligned-0.1.1.2-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-unaligned.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-unaligned
version:              0.1.1.2
visibility:           public
id:                   primitive-unaligned-0.1.1.2-8URWCuiw0WZ5Vntle5AIbk
key:                  primitive-unaligned-0.1.1.2-8URWCuiw0WZ5Vntle5AIbk
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           Andrew Martin <andrew.thaddeus@gmail.com>
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unaligned
synopsis:             Unaligned access to primitive arrays
description:
    Unaligned access to primitive arrays. The offsets are given in bytes rather than elements.

category:             Data
abi:                  fec9f580a9af6c01c90fa3718f7f5630
exposed:              True
exposed-modules:      Data.Primitive.ByteArray.Unaligned
hidden-modules:       Data.Primitive.Unaligned.Mach
import-dirs:          /usr/lib/ghc-9.2.8/site-local/primitive-unaligned-0.1.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primitive-unaligned-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unaligned
hs-libraries:         HSprimitive-unaligned-0.1.1.2-8URWCuiw0WZ5Vntle5AIbk
depends:
    base-4.16.4.0 primitive-0.7.4.0-FVB8RLw7kwa2mbgh0KVHMG

haddock-interfaces:
    /usr/share/doc/haskell-primitive-unaligned/html/primitive-unaligned.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unaligned/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-unaligned-0.1.1.2-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-unaligned.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-unaligned
version:              0.1.1.2
visibility:           public
id:                   primitive-unaligned-0.1.1.2-LtksY5PCmfRKbqkfdsFlK2
key:                  primitive-unaligned-0.1.1.2-LtksY5PCmfRKbqkfdsFlK2
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           Andrew Martin <andrew.thaddeus@gmail.com>
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unaligned
synopsis:             Unaligned access to primitive arrays
description:
    Unaligned access to primitive arrays. The offsets are given in bytes rather than elements.

category:             Data
abi:                  e600d581848efb022245b731544fa432
exposed:              True
exposed-modules:      Data.Primitive.ByteArray.Unaligned
hidden-modules:       Data.Primitive.Unaligned.Mach
import-dirs:          /usr/lib/ghc-9.2.8/site-local/primitive-unaligned-0.1.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primitive-unaligned-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unaligned
hs-libraries:         HSprimitive-unaligned-0.1.1.2-LtksY5PCmfRKbqkfdsFlK2
depends:
    base-4.16.4.0 primitive-0.7.4.0-AA8L6ftl9K2CnnGUysF0H7

haddock-interfaces:
    /usr/share/doc/haskell-primitive-unaligned/html/primitive-unaligned.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unaligned/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
